@@ -3,7 +3,7 @@
 import uuid
 from datetime import datetime
 from enum import Enum
-from typing import List, Optional, Any, Union, Dict
+from typing import List, Optional, Any, Union, Dict, Type
 
 from pydantic import BaseModel, Field, ConfigDict, model_validator
 
@@ -227,12 +227,19 @@ class AssistantChatRequest(BaseModel):
         default=None, description="Provide additional metadata"
     )
     tools_config: Optional[List[ToolConfig]] = None
+    output_schema: Optional[dict | Type[BaseModel]] = Field(
+        default=None,
+        description="Structured output schema for the agent. \
+            If specified, `generated` field in response will have the same type",
+    )
 
 
 class BaseModelResponse(BaseModel):
     """Model for chat response from assistant."""
 
-    generated: str = Field(description="Generated response error_message")
+    generated: str | dict | BaseModel = Field(
+        description="Generated response. If output_schema in request is specified, corresponds with its type"
+    )
     time_elapsed: Optional[float] = Field(
         default=None, alias="timeElapsed", description="Time taken for generation"
     )
